pub fn resolve_path(value: &CborValue, path: &str) -> Option<CborValue>Expand description
Resolve a dot-path from a CborValue map. e.g., resolve_path(value, “output.label”) traverses into nested maps. Returns None if any segment is missing or the value is not a map at an intermediate step. Empty path returns the value itself.